@@ -7,6 +7,4 @@
 ( cd ./usr/lib ; ln -sf libyaz.so.2.0.0 libyaz.so.2 )
 ( cd ./usr/lib ; rm -rf libyazthread.so.2 )
 ( cd ./usr/lib ; ln -sf libyazthread.so.2.0.0 libyazthread.so.2 )
-( cd ./usr/share ; rm -rf doc )
-( cd ./usr/share ; ln -sf ../doc doc )
 
